@@ -8,7 +8,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.1-3'
+Version = '1.1-5'
 
 import os
 import sys
@@ -20,64 +20,67 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 from swappolubeUI import *
+from swappolubeSettings import *
 
 ##############################################################
 
-PathTemp      = '/home/user/.swappolube'       # temp path of files
-PathApp       = '/opt/swappolube'              # application path
-PathSystem    = '/etc/event.d'                 # main path
-ConfigTemp    = 'swappolube_config_temp'       # name of temp config file
-ConfigCustom  = 'configCustom.py'              # name of custom config file
-ConfigMain    = 'tuning'                       # tuning file
+PathTemp       = '/home/user/.swappolube'       # temp path of files
+PathApp        = '/opt/swappolube'              # application path
+PathSystem     = '/etc/event.d'                 # main path
+ConfigTemp     = 'swappolube_config_temp'       # name of temp config file
+ConfigCustom   = 'configCustom.py'              # name of custom config file
+ConfigMain     = 'tuning'                       # tuning file
+PathSystemUi   = '/etc/systemui'
+ConfigSystemUi = 'swappolube.xml'
 
 ##############################################################
 
 def checkFile(Path, File):       
-    ''' Check if a file exists. '''
+     ''' Check if a file exists. '''
 
-    try:
-        f = open(Path + "/" + File, 'r')
-        f.close()
-        return True
-    except:
-        return False
+     try:
+         f = open(Path + "/" + File, 'r')
+         f.close()
+         return True
+     except:
+         return False
 
 def checkMMC1():
-    ''' Check if mmc1 installed. '''
+     ''' Check if mmc1 installed. '''
     
-    try:
-        f = open('/sys/block/mmcblk1/queue/nr_requests', 'r')
-        f.close()
-        return True
-    except:
-        return False
+     try:
+         f = open('/sys/block/mmcblk1/queue/nr_requests', 'r')
+         f.close()
+         return True
+     except:
+         return False
         
 def showMessage(message):        
-    ''' Method to display a message to the user that waits for an action. '''
+     ''' Method to display a message to the user that waits for an action. '''
 
-    os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
+     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications \
                org.freedesktop.Notifications.SystemNoteDialog \
                string:"%s" uint32:0 string:"OK"' % message)          
 
 def showQuickMessage(message):   
-    ''' Method to display shortly a message to the user. '''
+     ''' Method to display shortly a message to the user. '''
 
-    os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
+     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications \
                org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
 def doUpdateConfig():            
-    ''' Update the config file with the edited. '''
+     ''' Update the config file with the edited. '''
 
-    time.sleep(1)
-    try:
-       os.system('sudo %s/updateTuning copyTuning_temp' % PathApp)
-    except:
-       return False
-    else: 
-       return True
+     time.sleep(1)
+     try:
+         os.system('sudo %s/updateSettings copyTuning_temp' % PathApp)
+     except:
+         return False
+     else: 
+         return True
        
 class SwappolubeAbout(QtGui.QMainWindow):
     '''About Window'''
@@ -96,10 +99,10 @@ class SwappolubeAbout(QtGui.QMainWindow):
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
         #Kinetic scroller is available on Maemo and should be on meego
         try:
-            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
-            scroller.setEnabled(True)
+             scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+             scroller.setEnabled(True)
         except:
-            pass
+             pass
 
         aboutLayout = QVBoxLayout(awidget)
 
@@ -160,7 +163,7 @@ class SwappolubeAbout(QtGui.QMainWindow):
         QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/Swappolube'))
     def open_bugtracker(self):
         QDesktopServices.openUrl(QUrl('https://bugs.maemo.org'))
-
+        
 class MyMainWindow(QtGui.QMainWindow):
         def __init__(self, parent=None):
         
@@ -184,28 +187,61 @@ class MyMainWindow(QtGui.QMainWindow):
              QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
              QtCore.QObject.connect(self.ui.actionRestoreDefault, QtCore.SIGNAL('triggered()'), self.doRestoreDefault)
-             QtCore.QObject.connect(self.ui.actionDeleteTunings, QtCore.SIGNAL('triggered()'), self.doDeleteTunings)
-             
+             QtCore.QObject.connect(self.ui.actionDeleteTuningFile, QtCore.SIGNAL('triggered()'), self.doDeleteTuningFile)
+             QtCore.QObject.connect(self.ui.actionAddPowerKeyEntry, QtCore.SIGNAL('triggered()'), self.doAddPowerKeyEntry)
+             QtCore.QObject.connect(self.ui.actionRemovePowerKeyEntry, QtCore.SIGNAL('triggered()'), self.doRemovePowerKeyEntry)
+               ##Enable only the valid menu entry 
+             if checkFile(PathSystem, ConfigMain) == False:
+                 self.ui.actionDeleteTuningFile.setEnabled(False)
+               
+             if checkFile(PathSystemUi, ConfigSystemUi) == True:
+                 self.ui.actionAddPowerKeyEntry.setEnabled(False)
+             else:
+                 self.ui.actionRemovePowerKeyEntry.setEnabled(False)
+
              ##Set current values in the GUI
              self.doSetCurrent()
 
         ##Create Methods
                 
         def doAbout(self):
-        
-             stackwindow =SwappolubeAbout(self)
+             '''Open the about window.'''
+             
+             stackwindow = SwappolubeAbout(self)
              stackwindow.show()
 
-        def doDeleteTunings(self):
+        def doAddPowerKeyEntry(self):
+             '''Add entry in the Power Key menu'''
+             
+             os.system('sudo %s/updateSettings addPowerKeyEntry' % PathApp )
+             self.ui.actionAddPowerKeyEntry.setEnabled(False)
+             self.ui.actionRemovePowerKeyEntry.setEnabled(True)
+             os.system('sudo %s/updateSettings updatePowerKeyEntry' % PathApp )
+             message = 'Added entry in the Power Key Menu'
+             showQuickMessage(message)
+
+        def doRemovePowerKeyEntry(self):
+             '''Remove entry from the Power Key menu'''
+
+             os.system('sudo %s/updateSettings deletePowerKeyEntry' % PathApp )
+             self.ui.actionAddPowerKeyEntry.setEnabled(True)
+             self.ui.actionRemovePowerKeyEntry.setEnabled(False)
+             os.system('sudo %s/updateSettings updatePowerKeyEntry' % PathApp )
+             message = 'Removed entry from the Power Key Menu'
+             showQuickMessage(message)
         
-             os.system('sudo %s/updateTuning deleteTuning' % PathApp)
+        def doDeleteTuningFile(self):
+             '''Delete the tuning file'''
+             
+             os.system('sudo %s/updateSettings deleteTuning' % PathApp)
              if checkFile(PathSystem, ConfigMain) == True:
-                message = 'The tuning file could not be deleted.\
+                 message = 'The tuning file could not be deleted.\
                            \nPlease delete it manually.'
              else: 
-                message = 'The tuning file has been removed from the boot sequence.\
+                 message = 'The tuning file has been removed from the boot sequence.\
                            \nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
+             self.ui.actionDeleteTuningFile.setEnabled(False)
 
         def doRestoreDefault(self): 
              ''' Apply the the default values.'''
@@ -214,27 +250,27 @@ class MyMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
              
              ##Update the values.
-             os.system('sudo %s/updateTuning KillAllocatingTask 0' % PathApp )
-             os.system('sudo %s/updateTuning PageCluster 5' % PathApp )
-             os.system('sudo %s/updateTuning LaptopMode 0' % PathApp )
-             os.system('sudo %s/updateTuning DirtyExpireCentisecs 500' % PathApp )
-             os.system('sudo %s/updateTuning TCPTimestamps 1' % PathApp )
-             os.system('sudo %s/updateTuning DirtyWritebackCentisecs 500' % PathApp )
-             os.system('sudo %s/updateTuning TCPNoMetricsSave 0' % PathApp )
-             os.system('sudo %s/updateTuning DirtyRatio 40' % PathApp )
-             os.system('sudo %s/updateTuning Swappiness 100' % PathApp )
-             os.system('sudo %s/updateTuning DirtyBGDRatio 10' % PathApp )
-             os.system('sudo %s/updateTuning VFSCachePressure 100' % PathApp )
+             os.system('sudo %s/updateSettings KillAllocatingTask 0' % PathApp )
+             os.system('sudo %s/updateSettings PageCluster 5' % PathApp )
+             os.system('sudo %s/updateSettings LaptopMode 0' % PathApp )
+             os.system('sudo %s/updateSettings DirtyExpireCentisecs 500' % PathApp )
+             os.system('sudo %s/updateSettings TCPTimestamps 1' % PathApp )
+             os.system('sudo %s/updateSettings DirtyWritebackCentisecs 500' % PathApp )
+             os.system('sudo %s/updateSettings TCPNoMetricsSave 0' % PathApp )
+             os.system('sudo %s/updateSettings DirtyRatio 40' % PathApp )
+             os.system('sudo %s/updateSettings Swappiness 100' % PathApp )
+             os.system('sudo %s/updateSettings DirtyBGDRatio 10' % PathApp )
+             os.system('sudo %s/updateSettings VFSCachePressure 100' % PathApp )
              #new options in ver. 1.1-1
-             os.system('sudo %s/updateTuning mmc0requests 128' % PathApp )
+             os.system('sudo %s/updateSettings mmc0requests 128' % PathApp )
              if checkMMC1() == True:
-                os.system('sudo %s/updateTuning mmc1requests 128' % PathApp )
-             os.system('sudo %s/updateTuning minFreekbytes 2039' % PathApp )
+                 os.system('sudo %s/updateSettings mmc1requests 128' % PathApp )
+             os.system('sudo %s/updateSettings minFreekbytes 2039' % PathApp )
              
              if checkFile(PathSystem, ConfigMain) == True:
-                message = 'The default values have been restored to the system.\n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
+                 message = 'The default values have been restored to the system.\n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
              else:   
-                message = 'The default values have been restored to the system.'
+                 message = 'The default values have been restored to the system.'
              showMessage(message)
              
              ##Set current values in the GUI
@@ -265,34 +301,34 @@ class MyMainWindow(QtGui.QMainWindow):
              radioMinFreekbytes           = '0'
 
              if self.ui.radioSwappiness.isChecked() == True:
-                radioSwappiness              = '1'
+                 radioSwappiness              = '1'
              if self.ui.radioDirtyRatio.isChecked() == True:
-                radioDirtyRatio              = '1'
+                 radioDirtyRatio              = '1'
              if self.ui.radioDirtyBGDRatio.isChecked() == True:
-                radioDirtyBGDRatio           = '1'
+                 radioDirtyBGDRatio           = '1'
              if self.ui.radioDirtyExpireCentisecs.isChecked() == True:
-                radioDirtyExpireCentisecs    = '1'
+                 radioDirtyExpireCentisecs    = '1'
              if self.ui.radioDirtyWritebackCentisecs.isChecked() == True:
-                radioDirtyWritebackCentisecs = '1'
+                 radioDirtyWritebackCentisecs = '1'
              if self.ui.radioPageCluster.isChecked() == True:
-                radioPageCluster             = '1'
+                 radioPageCluster             = '1'
              if self.ui.radioVFSCachePressure.isChecked() == True:
-                radioVFSCachePressure        = '1'
+                 radioVFSCachePressure        = '1'
              if self.ui.radioLaptopMode.isChecked() == True:
-                radioLaptopMode              = '1'
+                 radioLaptopMode              = '1'
              if self.ui.radioKillAllocatingTask.isChecked() == True:
-                radioKillAllocatingTask      = '1'
+                 radioKillAllocatingTask      = '1'
              if self.ui.radioTCPTimestamps.isChecked() == True:
-                radioTCPTimestamps           = '1'
+                 radioTCPTimestamps           = '1'
              if self.ui.radioTCPNoMetricsSave.isChecked() == True:
-                radioTCPNoMetricsSave        = '1'
+                 radioTCPNoMetricsSave        = '1'
 
              if self.ui.radiommc0requests.isChecked() == True:
-                radiommc0requests        = '1'
+                 radiommc0requests        = '1'
              if self.ui.radiommc1requests.isChecked() == True:
-                radiommc1requests        = '1'
+                 radiommc1requests        = '1'
              if self.ui.radioMinFreekbytes.isChecked() == True:
-                radioMinFreekbytes        = '1'
+                 radioMinFreekbytes        = '1'
              
              Swappiness                   = self.ui.lineSwappiness.text()
              DirtyRatio                   = self.ui.lineDirtyRatio.text()
@@ -304,27 +340,26 @@ class MyMainWindow(QtGui.QMainWindow):
              LaptopMode                   = self.ui.lineLaptopMode.text()
              
              mmc0requests                 = self.ui.linemmc0requests.text()
-             #if checkMMC1() == True:
              mmc1requests                 = self.ui.linemmc1requests.text()
              minFreekbytes                = self.ui.lineMinFreekbytes.text()
              
-             if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
-                KillAllocatingTask = '1'
+             if self.ui.checkBoxKillAllocatingTask.isChecked() == True:
+                 KillAllocatingTask = '1'
              else:
-                KillAllocatingTask = '0'
+                 KillAllocatingTask = '0'
              if self.ui.checkBoxTCPTimestamps.isChecked() == True:
-                TCPTimestamps = '1'
+                 TCPTimestamps = '1'
              else:
-                TCPTimestamps = '0'
+                 TCPTimestamps = '0'
              if self.ui.checkBoxTCPNoMetricsSave.isChecked() == True:
-                TCPNoMetricsSave = '1'
+                 TCPNoMetricsSave = '1'
              else:
-                TCPNoMetricsSave = '0'   
+                 TCPNoMetricsSave = '0'   
                 
              ##Write values to the custom file.
              
              try:
-                os.system('echo "radioSwappiness = %s\
+                 os.system('echo "radioSwappiness = %s\
                              \nSwappiness = %s\
                              \nradioDirtyRatio = %s\
                              \nDirtyRatio = %s\
@@ -367,11 +402,11 @@ class MyMainWindow(QtGui.QMainWindow):
                                                                 radioMinFreekbytes, minFreekbytes,
                                                                 PathApp, ConfigCustom ) )
 
-                message = 'The custom settings have been saved.'
-                showMessage(message)             
+                 message = 'The custom settings have been saved.'
+                 showMessage(message)             
              except:
-                message = 'ERROR: The custom settings could not be saved.'
-                showMessage(message)             
+                 message = 'ERROR: The custom settings could not be saved.'
+                 showMessage(message)             
                 
         def doSetCurrent(self):     
              ''' Set CURRENT values in the GUI''' ##FIXME: split reading and setting into seperate methods!!!
@@ -396,19 +431,19 @@ class MyMainWindow(QtGui.QMainWindow):
              ##Set Values for checkboxes
              
              if os.popen('cat /proc/sys/vm/oom_kill_allocating_task').read().strip('\n') == '1':
-                self.ui.checkBoxKillAllocatingTask.setChecked(True)
+                 self.ui.checkBoxKillAllocatingTask.setChecked(True)
              else:
-                self.ui.checkBoxKillAllocatingTask.setChecked(False)
+                 self.ui.checkBoxKillAllocatingTask.setChecked(False)
 
              if os.popen('cat /proc/sys/net/ipv4/tcp_timestamps').read().strip('\n') == '1':
-               self.ui.checkBoxTCPTimestamps.setChecked(True)
+                 self.ui.checkBoxTCPTimestamps.setChecked(True)
              else:
-               self.ui.checkBoxTCPTimestamps.setChecked(False)
+                 self.ui.checkBoxTCPTimestamps.setChecked(False)
 
              if os.popen('cat /proc/sys/net/ipv4/tcp_no_metrics_save').read().strip('\n') == '1':
-               self.ui.checkBoxTCPNoMetricsSave.setChecked(True)
+                 self.ui.checkBoxTCPNoMetricsSave.setChecked(True)
              else:
-               self.ui.checkBoxTCPNoMetricsSave.setChecked(False)
+                 self.ui.checkBoxTCPNoMetricsSave.setChecked(False)
 
              ##Set values for lineEdits
              LaptopMode = os.popen('cat /proc/sys/vm/laptop_mode').read().strip('\n')
@@ -436,12 +471,12 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.lineMinFreekbytes.setText("%s" % minFreekbytes)
              
              if checkMMC1() == True:
-                mmc1requests = os.popen('cat /sys/block/mmcblk1/queue/nr_requests').read().strip('\n')
-                self.ui.linemmc1requests.setText("%s" % mmc1requests)
+                 mmc1requests = os.popen('cat /sys/block/mmcblk1/queue/nr_requests').read().strip('\n')
+                 self.ui.linemmc1requests.setText("%s" % mmc1requests)
              else:
-                self.ui.linemmc1requests.setText("128")
-                self.ui.linemmc1requests.setEnabled(False)
-                self.ui.radiommc1requests.setEnabled(False)
+                 self.ui.linemmc1requests.setText("128")
+                 self.ui.linemmc1requests.setEnabled(False)
+                 self.ui.radiommc1requests.setEnabled(False)
                 
              message = 'The CURRENT configuration options are shown.'
              showQuickMessage(message)
@@ -524,37 +559,37 @@ class MyMainWindow(QtGui.QMainWindow):
                 
                 #now set those checkboxes=1 to True 
                 if configCustom.radioSwappiness == 1:
-                   self.ui.radioSwappiness.setChecked(True)
+                     self.ui.radioSwappiness.setChecked(True)
                 if configCustom.radioDirtyRatio == 1:
-                   self.ui.radioDirtyRatio.setChecked(True)
+                     self.ui.radioDirtyRatio.setChecked(True)
                 if configCustom.radioDirtyBGDRatio == 1:
-                   self.ui.radioDirtyBGDRatio.setChecked(True)
+                     self.ui.radioDirtyBGDRatio.setChecked(True)
                 if configCustom.radioDirtyExpireCentisecs == 1:
-                   self.ui.radioDirtyExpireCentisecs.setChecked(True)
+                     self.ui.radioDirtyExpireCentisecs.setChecked(True)
                 if configCustom.radioDirtyWritebackCentisecs == 1:
-                   self.ui.radioDirtyWritebackCentisecs.setChecked(True)
+                     self.ui.radioDirtyWritebackCentisecs.setChecked(True)
                 if configCustom.radioPageCluster == 1:
-                   self.ui.radioPageCluster.setChecked(True)
+                     self.ui.radioPageCluster.setChecked(True)
                 if configCustom.radioVFSCachePressure == 1:
-                   self.ui.radioVFSCachePressure.setChecked(True)
+                     self.ui.radioVFSCachePressure.setChecked(True)
                 if configCustom.radioLaptopMode == 1:
-                   self.ui.radioLaptopMode.setChecked(True)
+                     self.ui.radioLaptopMode.setChecked(True)
                 if configCustom.radioKillAllocatingTask == 1:
-                   self.ui.radioKillAllocatingTask.setChecked(True)
+                     self.ui.radioKillAllocatingTask.setChecked(True)
                 if configCustom.radioTCPTimestamps == 1:
-                   self.ui.radioTCPTimestamps.setChecked(True)
+                     self.ui.radioTCPTimestamps.setChecked(True)
                 if configCustom.radioTCPNoMetricsSave == 1:
-                   self.ui.radioTCPNoMetricsSave.setChecked(True)                   
+                     self.ui.radioTCPNoMetricsSave.setChecked(True)                   
 
                 if configCustom.radiommc0requests == 1:
-                    self.ui.radiommc0requests.setChecked(True)
+                     self.ui.radiommc0requests.setChecked(True)
                 if configCustom.radiommc1requests == 1:
-                    self.ui.radiommc1requests.setChecked(True)
+                     self.ui.radiommc1requests.setChecked(True)
                 if configCustom.radioMinFreekbytes == 1:
-                    self.ui.radioMinFreekbytes.setChecked(True)
+                     self.ui.radioMinFreekbytes.setChecked(True)
                    
                 if checkMMC1() == True:
-                    self.ui.linemmc1requests.setText("%s" % configCustom.mmc1requests)
+                     self.ui.linemmc1requests.setText("%s" % configCustom.mmc1requests)
                
                 self.ui.lineSwappiness.setText("%s" % configCustom.Swappiness)
                 self.ui.lineDirtyRatio.setText("%s" % configCustom.DirtyRatio)
@@ -602,48 +637,48 @@ class MyMainWindow(QtGui.QMainWindow):
              minFreekbytes              = self.ui.lineMinFreekbytes.text()
                
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
-                KillAllocatingTask = '1'
+                 KillAllocatingTask = '1'
              else:
-                KillAllocatingTask = '0'
+                 KillAllocatingTask = '0'
              if self.ui.checkBoxTCPTimestamps.isChecked() == True:
-                TCPTimestamps = '1'
+                 TCPTimestamps = '1'
              else:
-                TCPTimestamps = '0'
+                 TCPTimestamps = '0'
              if self.ui.checkBoxTCPNoMetricsSave.isChecked() == True:
-                TCPNoMetricsSave = '1'
+                 TCPNoMetricsSave = '1'
              else:
-                TCPNoMetricsSave = '0'
+                 TCPNoMetricsSave = '0'
               
              ##Update the values.
              if self.ui.radioKillAllocatingTask.isChecked() == True:
-               os.system('sudo %s/updateTuning KillAllocatingTask %s' % (PathApp, KillAllocatingTask) )
+                 os.system('sudo %s/updateSettings KillAllocatingTask %s' % (PathApp, KillAllocatingTask) )
              if self.ui.radioPageCluster.isChecked() == True:
-               os.system('sudo %s/updateTuning PageCluster %s' % (PathApp, PageCluster) )
+                 os.system('sudo %s/updateSettings PageCluster %s' % (PathApp, PageCluster) )
              if self.ui.radioLaptopMode.isChecked() == True:
-               os.system('sudo %s/updateTuning LaptopMode %s' % (PathApp, LaptopMode) )
+                 os.system('sudo %s/updateSettings LaptopMode %s' % (PathApp, LaptopMode) )
              if self.ui.radioDirtyExpireCentisecs.isChecked() == True:
-               os.system('sudo %s/updateTuning DirtyExpireCentisecs %s' % (PathApp, DirtyExpireCentisecs) )
+                 os.system('sudo %s/updateSettings DirtyExpireCentisecs %s' % (PathApp, DirtyExpireCentisecs) )
              if self.ui.radioTCPTimestamps.isChecked() == True:
-               os.system('sudo %s/updateTuning TCPTimestamps %s' % (PathApp, TCPTimestamps) )
+                 os.system('sudo %s/updateSettings TCPTimestamps %s' % (PathApp, TCPTimestamps) )
              if self.ui.radioDirtyWritebackCentisecs.isChecked() == True:
-               os.system('sudo %s/updateTuning DirtyWritebackCentisecs %s' % (PathApp, DirtyWritebackCentisecs) )
+                 os.system('sudo %s/updateSettings DirtyWritebackCentisecs %s' % (PathApp, DirtyWritebackCentisecs) )
              if self.ui.radioTCPNoMetricsSave.isChecked() == True:
-               os.system('sudo %s/updateTuning TCPNoMetricsSave %s' % (PathApp, TCPNoMetricsSave) )
+                 os.system('sudo %s/updateSettings TCPNoMetricsSave %s' % (PathApp, TCPNoMetricsSave) )
              if self.ui.radioDirtyRatio.isChecked() == True:
-               os.system('sudo %s/updateTuning DirtyRatio %s' % (PathApp, DirtyRatio) )
+                 os.system('sudo %s/updateSettings DirtyRatio %s' % (PathApp, DirtyRatio) )
              if self.ui.radioSwappiness.isChecked() == True:
-               os.system('sudo %s/updateTuning Swappiness %s' % (PathApp, Swappiness) )
+                 os.system('sudo %s/updateSettings Swappiness %s' % (PathApp, Swappiness) )
              if self.ui.radioDirtyBGDRatio.isChecked() == True:
-               os.system('sudo %s/updateTuning DirtyBGDRatio %s' % (PathApp, DirtyBGDRatio) )
+                 os.system('sudo %s/updateSettings DirtyBGDRatio %s' % (PathApp, DirtyBGDRatio) )
              if self.ui.radioVFSCachePressure.isChecked() == True:
-               os.system('sudo %s/updateTuning VFSCachePressure %s' % (PathApp, VFSCachePressure) )
+                 os.system('sudo %s/updateSettings VFSCachePressure %s' % (PathApp, VFSCachePressure) )
 
              if self.ui.radiommc0requests.isChecked() == True:
-               os.system('sudo %s/updateTuning mmc0requests %s' % (PathApp, mmc0requests) )
+                 os.system('sudo %s/updateSettings mmc0requests %s' % (PathApp, mmc0requests) )
              if self.ui.radiommc1requests.isChecked() == True:
-               os.system('sudo %s/updateTuning mmc1requests %s' % (PathApp, mmc1requests) )
+                 os.system('sudo %s/updateSettings mmc1requests %s' % (PathApp, mmc1requests) )
              if self.ui.radioMinFreekbytes.isChecked() == True:
-               os.system('sudo %s/updateTuning minFreekbytes %s' % (PathApp, minFreekbytes) )
+                 os.system('sudo %s/updateSettings minFreekbytes %s' % (PathApp, minFreekbytes) )
                
              message = 'The new values have been applied to the system.\n\nINFO:They will revert to their defaults on the next reboot.\
                         \nIf you want them to persist use the Store button.'
@@ -670,30 +705,30 @@ class MyMainWindow(QtGui.QMainWindow):
              minFreekbytes              = self.ui.lineMinFreekbytes.text()
                
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
-                KillAllocatingTask = '1'
+                 KillAllocatingTask = '1'
              else:
-                KillAllocatingTask = '0'
+                 KillAllocatingTask = '0'
              if self.ui.checkBoxTCPTimestamps.isChecked() == True:
-                TCPTimestamps = '1'
+                 TCPTimestamps = '1'
              else:
-                TCPTimestamps = '0'
+                 TCPTimestamps = '0'
              if self.ui.checkBoxTCPNoMetricsSave.isChecked() == True:
-                TCPNoMetricsSave = '1'
+                 TCPNoMetricsSave = '1'
              else:
-                TCPNoMetricsSave = '0'
+                 TCPNoMetricsSave = '0'
             
              ##Update of the config file.
              if checkFile(PathTemp, ConfigTemp) == True:
                 try:
-                   os.remove( PathTemp + "/" + ConfigTemp )
+                     os.remove( PathTemp + "/" + ConfigTemp )
                 except:
-                   message = 'FATAL ERROR: The temp configuration file could not be removed.\nThe application will now exit..'
-                   showMessage(message)
-                   sys.exit(1)
+                     message = 'FATAL ERROR: The temp configuration file could not be removed.\nThe application will now exit..'
+                     showMessage(message)
+                     sys.exit(1)
                 else:
-                   pass 
+                     pass 
              else:
-                pass 
+                 pass 
 
              destination = open( PathTemp + "/" + ConfigTemp, "w" )
 
@@ -708,44 +743,46 @@ class MyMainWindow(QtGui.QMainWindow):
              destination.write('\n')
              destination.write('script\n')
              if self.ui.radioKillAllocatingTask.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/oom_kill_allocating_task\n' % KillAllocatingTask) 
+                 destination.write('       echo "%s" > /proc/sys/vm/oom_kill_allocating_task\n' % KillAllocatingTask) 
              if self.ui.radioPageCluster.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/page-cluster\n' % PageCluster) 
+                 destination.write('       echo "%s" > /proc/sys/vm/page-cluster\n' % PageCluster) 
              if self.ui.radioLaptopMode.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/laptop_mode\n' % LaptopMode) 
+                 destination.write('       echo "%s" > /proc/sys/vm/laptop_mode\n' % LaptopMode) 
              if self.ui.radioDirtyExpireCentisecs.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/dirty_expire_centisecs\n' % DirtyExpireCentisecs) 
+                 destination.write('       echo "%s" > /proc/sys/vm/dirty_expire_centisecs\n' % DirtyExpireCentisecs) 
              if self.ui.radioTCPTimestamps.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/net/ipv4/tcp_timestamps\n' % TCPTimestamps) 
+                 destination.write('       echo "%s" > /proc/sys/net/ipv4/tcp_timestamps\n' % TCPTimestamps) 
              if self.ui.radioDirtyWritebackCentisecs.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/dirty_writeback_centisecs\n' % DirtyWritebackCentisecs) 
+                 destination.write('       echo "%s" > /proc/sys/vm/dirty_writeback_centisecs\n' % DirtyWritebackCentisecs) 
              if self.ui.radioTCPNoMetricsSave.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/net/ipv4/tcp_no_metrics_save\n' % TCPNoMetricsSave) 
+                 destination.write('       echo "%s" > /proc/sys/net/ipv4/tcp_no_metrics_save\n' % TCPNoMetricsSave) 
              if self.ui.radioDirtyRatio.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/dirty_ratio\n' % DirtyRatio) 
+                 destination.write('       echo "%s" > /proc/sys/vm/dirty_ratio\n' % DirtyRatio) 
              if self.ui.radioSwappiness.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/swappiness\n' % Swappiness) 
+                 destination.write('       echo "%s" > /proc/sys/vm/swappiness\n' % Swappiness) 
              if self.ui.radioDirtyBGDRatio.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/dirty_background_ratio\n' % DirtyBGDRatio) 
+                 destination.write('       echo "%s" > /proc/sys/vm/dirty_background_ratio\n' % DirtyBGDRatio) 
              if self.ui.radioVFSCachePressure.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/vfs_cache_pressure\n' % VFSCachePressure) 
+                 destination.write('       echo "%s" > /proc/sys/vm/vfs_cache_pressure\n' % VFSCachePressure) 
              if self.ui.radiommc0requests.isChecked() == True:
-               destination.write('       echo "%s" > /sys/block/mmcblk0/queue/nr_requests\n' % mmc0requests)
+                 destination.write('       echo "%s" > /sys/block/mmcblk0/queue/nr_requests\n' % mmc0requests)
              if self.ui.radiommc1requests.isChecked() == True:
-               destination.write('       echo "%s" > /sys/block/mmcblk1/queue/nr_requests\n' % mmc1requests)
+                 destination.write('       echo "%s" > /sys/block/mmcblk1/queue/nr_requests\n' % mmc1requests)
              if self.ui.radioMinFreekbytes.isChecked() == True:
-               destination.write('       echo "%s" > /proc/sys/vm/min_free_kbytes\n' % minFreekbytes)
+                 destination.write('       echo "%s" > /proc/sys/vm/min_free_kbytes\n' % minFreekbytes)
 
              destination.write('end script\n')
              destination.close()
              
              ##Update destination file
              if doUpdateConfig() == True:
-                message = 'The new configuration has been created and copied to event.d folder.'
-                showMessage(message)
+                 message = 'The new configuration has been created and copied to event.d folder.'
+                 showMessage(message)
+                 self.ui.actionDeleteTuningFile.setEnabled(True)
+
              else:
-                message = 'FATAL ERROR: The new configuration could not be created.'
-                showMessage(message)
+                 message = 'FATAL ERROR: The new configuration could not be created.'
+                 showMessage(message)
             
 if __name__ == "__main__": 
         
